# equilibrator-pathway

Pathway analysis tools based on thermodynamic and kinetic models.

## Installation

The easiest way to use equilibrator-pathway is with virtualenv, PyPI, and Jupyter notebooks:
```
virtualenv -p python3 equilibrator
source equilibrator/bin/activate
pip install equilibrator-pathway jupyter jupyterlab
curl https://gitlab.com/equilibrator/equilibrator-pathway/raw/develop/examples/ecoli_noor_2016.ipynb > ecoli_noor_2016.ipynb
jupyter lab
```

